read_section_header

Function read_section_header 

fn read_section_header(
    reader: &mut Reader<ENSIGHT_GOLDER_BINARY_FORMAT_LINE_SIZE>,
) -> Result<String>
The first line of a section is the only place where the file is allowed to end