SectionEnd

Struct SectionEnd 

struct SectionEnd;
Marks “the section holds no further item”, as opposed to a read failure. Sections are only delimited by what the next line holds, so the readers have to report the end as an error and the callers must not confuse it with a truncated or unreadable file.